The Core (xentica\.core)
========================

.. automodule:: xentica.core

Base Classes (xentica\.core\.base)
----------------------------------

.. automodule:: xentica.core.base
    :members:
    :undoc-members:
    :show-inheritance:

Experiments (xentica\.core\.experiment)
---------------------------------------

.. automodule:: xentica.core.experiment
    :members:
    :undoc-members:
    :show-inheritance:

Properties (xentica\.core\.properties)
--------------------------------------

.. automodule:: xentica.core.properties
    :members:
    :undoc-members:
    :show-inheritance:

Variables (xentica\.core\.variables)
------------------------------------

.. automodule:: xentica.core.variables
    :members:
    :undoc-members:
    :show-inheritance:

Color Effects (xentica\.core\.color\_effects)
---------------------------------------------

.. automodule:: xentica.core.color_effects
    :members:
    :undoc-members:
    :show-inheritance:

Renderers (xentica\.core\.renderers)
------------------------------------

.. automodule:: xentica.core.renderers
    :members:
    :undoc-members:
    :show-inheritance:

Exceptions (xentica\.core\.exceptions)
--------------------------------------

.. automodule:: xentica.core.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

Mixins (xentica\.core\.mixins)
------------------------------

.. automodule:: xentica.core.mixins
    :members:
    :undoc-members:
    :show-inheritance:
